Trading API
===========

Comprehensive trading functionality including order management, position tracking, and portfolio management.

Order Management
----------------

.. currentmodule:: project_x_py

.. automodule:: project_x_py.order_manager
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

.. automodule:: project_x_py.position_manager
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

.. autoclass:: OrderManager
   :members:
   :undoc-members:
   :show-inheritance:

Order Factory Functions
~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: create_order_manager

Position Management
-------------------

.. autoclass:: PositionManager
   :members:
   :undoc-members:
   :show-inheritance:

Position Factory Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: create_position_manager

Trading Suite
-------------

.. autofunction:: create_trading_suite

Order Models
------------

.. autoclass:: project_x_py.models.Order
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: project_x_py.models.OrderPlaceResponse
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: project_x_py.models.BracketOrderResponse
   :members:
   :undoc-members:
   :show-inheritance:

Position Models
---------------

.. autoclass:: project_x_py.models.Position
   :members:
   :undoc-members:
   :show-inheritance:

Account Models
--------------

.. autoclass:: project_x_py.models.Account
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: project_x_py.models.Trade
   :members:
   :undoc-members:
   :show-inheritance: 